What’s new in version 1.2.3
===========================
Version available since January 26th 2023


New Features
------------

- IPOPT algorithm from cyipopt package added.
- Normalization of outputs and gradients to improve algorithms convergence.
- "Debug Nan" of Jax set True by default.

Contributors
------------
Lucas Agobert
